package com.nisum.controller;

import com.nisum.dto.EmployeeDto;
import com.nisum.model.impl.EmployeeImp;
import com.nisum.service.EmployeeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import java.util.Collection;


/*
    Controllers are what provide an API into the application. This is what an external user interacts with to initiate
    any sort of action in the application

    ** This employee controller contains CRUD methods to view, create, edit, and delete employees in a demo/toy/simple web app

    $$$ TODO: Create endpoints for /delete and /update
 */


@Controller
public class EmployeeController {

  @Autowired
  EmployeeService employeeService;

  @RequestMapping(value = "/", method = RequestMethod.GET)
  public String index(Model model) {
    Collection<EmployeeImp> employeeList = employeeService.getAllEmployees();
    model.addAttribute("employees", employeeList);
    return "index";
  }

  @RequestMapping(value = "/new", method = RequestMethod.GET)
  public String newEmployee(Model model) {
    model.addAttribute("employee", new EmployeeDto());
    return "new";
  }

  @RequestMapping(value = "/create", method = RequestMethod.POST)
  public String createEmployee(@ModelAttribute("employee") EmployeeDto employeeDto,
                               BindingResult bindingResult) {
    employeeService.createEmployee(employeeDto);
    return "redirect:/";
  }

}
